//
//  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
//  Copyright (C) 2012 - Pawel Zagorski
//
//  This file must be used under the terms of the CeCILL.
//  This source file is licensed as described in the file COPYING, which
//  you should have received as part of this distribution.  The terms
//  are also available at
//  http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


function block=AB_plot_groundtrack(block,flag)

previousprot = funcprot(0)

block_name = "AB_plot_groundtrack";
xcos_block_debug(block, flag, block_name);

select flag
  case 1 then
  // Output computation
    vec = block.inptr(1);
    if ~and(vec == zeros(3,1)) then
      vec = CL_co_car2sph(vec);
      vec = CL_rad2deg(vec);
      win_id = findobj("Tag", block.label);
      [color_id traj_color_id thickness traj_thickness steps data_bounds res coord]=AB_get_pg_parameters(block);
      //%CL_rad2deg = 180/%pi; //defining myself because it is faster
      //CL_init();
      //CL_plot_ephem([win_id.user_data vec], win_id, traj_color_id, [], ..
      //  area, traj_thickness);
      AB_plot_ephem(win_id, [win_id.user_data vec], traj_color_id, traj_thickness, data_bounds);
      win_id.user_data = vec;
    else
      time = getscicosvars("t0");
      if time <> 0 then
        warning(msprintf("\t%s : Encountered empty input vector at time = %f!\n", block_name, time));
      end
    end
  case 4 then
  // Initialization
    AB_check_param_number(block_name, block, 5, 1, 0);
    // Figure needs to be created or reused before any color() call to 
    // avoid creating empty graphic window
    win_id = findobj("Tag", block.label);
    if win_id == [] then			// create new plot
      win_id = figure("Tag", block.label,'Figure_name', ..
        'Groundtrack plot');
      win_id.background = color("white");
    else					// or reset the figure
      scf(win_id);
      clf();
    end         
    [color_id traj_color_id thickness traj_thickness steps area res coord]=AB_get_pg_parameters(block);
    axes_id = win_id.children;
    xlabel(axes_id, "longitude [degrees]");
    ylabel(axes_id, "latitude [degrees]");
    AB_plot_earthMap(win_id,color_id,steps,area,thickness,res,coord);
  case 5 then
  // Ending
    win_id = findobj("Tag", block.label);
    win_id.user_data = [];
  case 6 then
  // Initialization, fixed-point computation
    ;
  else
    error(msprintf(gettext("%s : Incorect flag %d"), block_name, flag));
end

endfunction


function [color_id, traj_color_id, thickness, traj_thickness, steps, area, res, coord]=AB_get_pg_parameters(block)

    thickness = block.ipar(1);
    traj_thickness = block.ipar(2);
    color_id = block.ipar(3);
    traj_color_id = block.ipar(4);
    steps = block.opar(1);
    area = block.opar(2); 
    res = block.opar(3); 
    coord = block.opar(4);

funcprot(previousprot)
endfunction

function [err] = AB_plot_pg_tick_steps(win_id, tick_steps, data_bounds)
    err = 1;
    if ~exists('win_id','local') then  
	err = -1; 
    else
	f = scf(win_id);

	if (size(data_bounds,1) <> 2 | size(data_bounds,2) <> 2)
	  CL__error('Invalid size for data_bounds');
	end
	if (data_bounds(2,1)<=data_bounds(1,1) | data_bounds(2,1)>data_bounds(1,1)+360)
	  CL__error('Invalid data bounds in longitude');
	end 
	if (data_bounds(2,2)<=data_bounds(1,2) | data_bounds(1,2) < -90 | data_bounds(2,2) > 90)
	  CL__error('Invalid data bounds in latitude');
	end 

	if (tick_steps <> [])
	  if (length(tick_steps) <> 2)
	    CL__error('Invalid size for tick_steps');
	  end 
	  if (tick_steps(1) <= 0 | tick_steps(2) <= 0)
	    CL__error('Invalid values for tick_steps');
	  end 
	end	

	// plot
	immediate_drawing_save = f.immediate_drawing; // store field
	f.immediate_drawing = "off"; 

	// adjustments (grid, databounds)
	a = gca();
	a.data_bounds = data_bounds;
	a.tight_limits = "on";

	bticks = [ tick_steps(1) * floor(data_bounds(1,:)/tick_steps(1)); 
		   tick_steps(2) * ceil((data_bounds(2,:))/tick_steps(2)) ];

	if (tick_steps <> [])
	  bticks = [ tick_steps(1)*floor(data_bounds(1,:)/tick_steps(1)); 
		     tick_steps(2)*ceil((data_bounds(2,:))/tick_steps(2)) ];

	  x_ticks = bticks(1,1) : tick_steps(1) : bticks(2,1);
	  y_ticks = bticks(1,2) : tick_steps(2) : bticks(2,2);

	  // strsplit+msprintf : used to avoid "string"
	  x_ticks_labels = strsplit( stripblanks( msprintf("%.8g ",x_ticks')) , " ")' ; 
	  y_ticks_labels = strsplit( stripblanks( msprintf("%.8g ",y_ticks')) , " ")' ;

	  a.x_ticks = tlist(["ticks", "locations", "labels"], x_ticks, x_ticks_labels ); 
	  a.y_ticks = tlist(["ticks", "locations", "labels"], y_ticks, y_ticks_labels ); 
	end

	CL_g_stdaxes(a);
	a.axes_visible = ["on", "on", "on"];

	f.immediate_drawing = immediate_drawing_save; // restore field
    end

endfunction

function [err] = AB_plot_ephem(win_id, pos_sph, traj_color_id, thickness, data_bounds)
    err = 1;
    if ~exists('win_id','local') then  
	err = -1; 
    else
	f = scf(win_id);

	// plot
	immediate_drawing_save = f.immediate_drawing; // store field
	f.immediate_drawing = "off"; 

	// interval in longitude containing the view
	bmin = (data_bounds(1,1)+data_bounds(2,1))/2 - 180; 
	bmax = (data_bounds(1,1)+data_bounds(2,1))/2 + 180; 
	box = [data_bounds(1,1), data_bounds(1,2), data_bounds(2,1),data_bounds(2,2)];

	// plot curve (never empty)
	//[x, y] = CL__plot_genxy(pos_sph(1,:), pos_sph(2,:), bmin, bmax);
	//if ~or(isnan([x y])) & (x <= bmax) & (x >= bmin)
	//    plot2d(x, y, rect=box);
	//    h = CL_g_select(gce(), "Polyline"); 
	//    h.foreground = traj_color_id; 
	//    h.thickness = thickness; 
	//end
	a = gca();
	if(size(a.children, "r") < 2)
		[x, y] = CL__plot_genxy(pos_sph(1,:), pos_sph(2,:), bmin, bmax);
		plot2d(x, y, rect=box);
		h = CL_g_select(gce(), "Polyline"); 
		h.foreground = traj_color_id; 
		h.thickness = thickness;		
	else//if ~or(isnan([x y])) & (x <= bmax) & (x >= bmin)
		pos_current = a.children(1).children.data';	// Data so far is transposed
		[x, y] = CL__plot_genxy([pos_current(1,:), pos_sph(1,:)], [pos_current(2,:), pos_sph(2,:)], bmin, bmax);
		a.children(1).children.data = [x',y'];
	end

	// adjustments (grid, databounds)
	//a = gca();
	//a.data_bounds = data_bounds;
	//a.tight_limits = "on";

	f.immediate_drawing = immediate_drawing_save; // restore field
    end
endfunction

function AB_plot_earthMap(win_id,color_id,tick_steps,data_bounds,thickness,res,coord)

if exists('win_id','local') then
  f = scf(win_id)
else
  f = gcf();
end

// error checking

if (size(data_bounds,1) <> 2 | size(data_bounds,2) <> 2)
  CL__error('Invalid size for data_bounds');
end
if (data_bounds(2,1)<=data_bounds(1,1) | data_bounds(2,1)>data_bounds(1,1)+360)
  CL__error('Invalid data bounds in longitude');
end 
if (data_bounds(2,2)<=data_bounds(1,2) | data_bounds(1,2) < -90 | data_bounds(2,2) > 90)
  CL__error('Invalid data bounds in latitude');
end 

if (tick_steps <> [])
  if (length(tick_steps) <> 2)
    CL__error('Invalid size for tick_steps');
  end 
  if (tick_steps(1) <= 0 | tick_steps(2) <= 0)
    CL__error('Invalid values for tick_steps');
  end 
end

// plot
immediate_drawing_save = f.immediate_drawing; // store field
f.immediate_drawing = "off"; 

// loading of the map (blocks separated by %nan)
// pts: size = 3xN
pts = CL_getEarthMap(res, coord); 

// interval in longitude containing the view
bmin = (data_bounds(1,1)+data_bounds(2,1))/2 - 180; 
bmax = (data_bounds(1,1)+data_bounds(2,1))/2 + 180; 

 // plot curve (degrees)
[x, y] = CL__plot_genxy(pts(1,:)*180/%pi, pts(2,:)*180/%pi, bmin, bmax);
//k = 1; 
//for i=1:size(xN, 2)
//    if ~or(isnan([xN(1,i) yN(1,i)]))
//	x(1,k) = xN(1,i);
//	y(1,k) = yN(1,i);
//	k=k+1;
//    end
//end 
box = [data_bounds(1,1), data_bounds(1,2), data_bounds(2,1),data_bounds(2,2)];
plot2d(x, y);
h = CL_g_select(gce(), "Polyline"); 
h.foreground = color_id; 
h.thickness = thickness; 


// adjustments (grid, databounds)
a = gca();
a.data_bounds = data_bounds;
a.tight_limits = "on";

if (tick_steps <> [])
  bticks = [ tick_steps(1)*floor(data_bounds(1,:)/tick_steps(1)); 
             tick_steps(2)*ceil((data_bounds(2,:))/tick_steps(2)) ];

  x_ticks = bticks(1,1) : tick_steps(1) : bticks(2,1);
  y_ticks = bticks(1,2) : tick_steps(2) : bticks(2,2);

  // strsplit+msprintf : used to avoid "string"
  x_ticks_labels = strsplit( stripblanks( msprintf("%.8g ",x_ticks')) , " ")' ; 
  y_ticks_labels = strsplit( stripblanks( msprintf("%.8g ",y_ticks')) , " ")' ;

  a.x_ticks = tlist(["ticks", "locations", "labels"], x_ticks, x_ticks_labels ); 
  a.y_ticks = tlist(["ticks", "locations", "labels"], y_ticks, y_ticks_labels ); 
end

CL_g_stdaxes(a);

f.immediate_drawing = immediate_drawing_save; // restore field

endfunction
