// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================


// Test flags
//<-- XCOS TEST -->
//<-- NO CHECK ERROR OUTPUT -->

//Load xcos test diagram for eci_to_ecf tests
[macros,path] = libraryinfo('xcos_aerolib');
result = importXcosDiagram(path + "../tests/unit_tests" +"/frame_conv_jacobian.zcos");
assert_checktrue(result);

//This diagram uses 4 variables : 
//  pos_in  : position input vectors
//  vel_in  : velocity input vectors
//  jacob_out : jacobian of the transformation (to_workspace)

pos_in = [3500.e3;2500.e3;5800.e3];
vel_in = [1.e3;3.e3;7.e3];
scicos_simulate(scs_m);

// Define expected values
exp_time = [0.3; 0.6; 0.9]; 
exp_jacob(:,:,1) =  [	-0.8745191  -0.4849911    0.   0.          0.           0.;  
		 	 0.4849911  -0.8745191    0.   0.          0.           0.;
			 0.          0.           1.   0.          0.           0.;  
			 0.0000354  -0.0000638    0.  -0.8745191  -0.4849911    0.;  
			 0.0000638   0.0000354    0.   0.4849911  -0.8745191    0.;  
			 0.          0.           0.   0.          0.           1.  ]
exp_jacob(:,:,2) =  [	 0.7350042  -0.6780625    0.   0.          0.           0.;  
			 0.6780625   0.7350042    0.   0.          0.           0.;  
			 0.          0.           1.   0.          0.           0.;  
			 0.0000494   0.0000536    0.   0.7350042  -0.6780625    0.;  
			-0.0000536   0.0000494    0.   0.6780625   0.7350042    0.;  
			 0.          0.           0.   0.          0.           1.; ]
exp_jacob(:,:,3) =  [	 0.4130526   0.9107072    0.   0.          0.           0.;  
			-0.9107072   0.4130526    0.   0.          0.           0.;  
			 0.          0.           1.   0.          0.           0.;  
			-0.0000664   0.0000301    0.   0.4130526   0.9107072    0.;  
			-0.0000301  -0.0000664    0.  -0.9107072   0.4130526    0.;  
			 0.          0.           0.   0.          0.           1.  ]

//Validate results
assert_checkalmostequal(exp_time, jacob_out.time, 1e-8);
assert_checkalmostequal(exp_jacob(:,:,1), jacob_out.values(:,:,1),1e-3);
assert_checkalmostequal(exp_jacob(:,:,2), jacob_out.values(:,:,2),1e-3);
assert_checkalmostequal(exp_jacob(:,:,3), jacob_out.values(:,:,3),1e-3);

